
# Titanoboa Project

🐍 Welcome to your Titanoboa project!

## Quickstart

```bash
boa init
boa compile
```

_For documentation, please run `mox --help` or visit [the Moccasin documentation](https://github.com/cyfrin/moccasin)_
